@@ -6,6 +6,7 @@ import sys, os
 import imp
 
 from pylogwatch.logwlib import PyLogConf
+from pylogwatch.utils import lockfile
 
 
 def load_cfg_module (cfgpath):
@@ -16,8 +17,13 @@ def load_cfg_module (cfgpath):
 
 if __name__=='__main__':
     p = optparse.OptionParser()
-    p.add_option('--config', '-c', default="config.py", help="Filesystem path to (python) configuration file [default: %default]")
+    p.add_option('--config', '-c', default="~/pylogconf.py", help="Filesystem path to (python) configuration file [default: %default]")
     options, arguments = p.parse_args()
+
+    # Check if we can obtain a lock - make sure we're the only process on this config
+    if not lockfile(os.path.realpath(options.config) + '.lck'):
+        sys.exit ('Cannot obtain a lock on %s' %  os.path.realpath(options.config))
+
     cfgmod = load_cfg_module(options.config)
     pl = PyLogConf(cfgmod)
     pl.run()
